@@ -16,27 +16,23 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-
 """Implementation of the 'aea launch' subcommand."""
-
-import os
-import subprocess  # nosec
 import sys
 from collections import OrderedDict
 from pathlib import Path
-from subprocess import Popen  # nosec
-from threading import Thread
 from typing import List, cast
 
 import click
 
 from aea.aea import AEA
 from aea.aea_builder import AEABuilder
-from aea.cli.run import run
 from aea.cli.utils.click_utils import AgentDirectory
 from aea.cli.utils.context import Context
 from aea.cli.utils.loggers import logger
 from aea.helpers.base import cd
+from aea.helpers.multiple_executor import ExecutorExceptionPolicies
+from aea.launcher import AEALauncher
+from aea.runner import AEARunner
 
 
 @click.command()
@@ -61,68 +57,57 @@ def _launch_agents(
     :return: None.
     """
     agents_directories = list(map(Path, list(OrderedDict.fromkeys(agents))))
-    if multithreaded:
-        failed = _launch_threads(click_context, agents_directories)
-    else:
-        failed = _launch_subprocesses(click_context, agents_directories)
-    logger.debug(f"Exit cli. code: {failed}")
-    sys.exit(failed)
-
-
-def _run_agent(click_context, agent_directory: str):
-    os.chdir(agent_directory)
-    click_context.invoke(run)
+    try:
+        if multithreaded:
+            failed = _launch_threads(agents_directories)
+        else:
+            failed = _launch_subprocesses(click_context, agents_directories)
+    except BaseException:  # pragma: no cover
+        logger.exception("Exception in launch agents.")
+        failed = -1
+    finally:
+        logger.debug(f"Exit cli. code: {failed}")
+        sys.exit(failed)
 
 
 def _launch_subprocesses(click_context: click.Context, agents: List[Path]) -> int:
     """
     Launch many agents using subprocesses.
 
-    :param agents: the click context.
+    :param click_context: the click context.
     :param agents: list of paths to agent projects.
     :return: execution status
     """
     ctx = cast(Context, click_context.obj)
-    processes = []
-    failed = 0
-    for agent_directory in agents:
-        process = Popen(  # nosec
-            [sys.executable, "-m", "aea.cli", "-v", ctx.verbosity, "run"],
-            cwd=str(agent_directory),
-        )
-        logger.info("Agent {} started...".format(agent_directory.name))
-        processes.append(process)
+
+    launcher = AEALauncher(
+        agents,
+        mode="multiprocess",
+        fail_policy=ExecutorExceptionPolicies.log_only,
+        log_level=ctx.verbosity,
+    )
 
     try:
-        for process in processes:
-            process.wait()
+        launcher.start()
     except KeyboardInterrupt:
         logger.info("Keyboard interrupt detected.")
     finally:
-        for agent_directory, process in zip(agents, processes):
-            result = process.poll()
-            if result is None:
-                try:
-                    process.wait()
-                except (subprocess.TimeoutExpired, KeyboardInterrupt):
-                    logger.info("Force shutdown {}...".format(agent_directory.name))
-                    process.kill()
+        launcher.stop()
 
-            logger.info(
-                "Agent {} terminated with exit code {}".format(
-                    agent_directory.name, process.returncode
-                )
-            )
-            if process.returncode not in [None, 0]:
-                failed += 1
-    return failed
+    for agent in launcher.failed:
+        logger.info(f"Agent {agent} terminated with exit code 1")
+
+    for agent in launcher.not_failed:
+        logger.info(f"Agent {agent} terminated with exit code 0")
+
+    return launcher.num_failed
 
 
-def _launch_threads(click_context: click.Context, agents: List[Path]) -> int:
+def _launch_threads(agents: List[Path]) -> int:
     """
     Launch many agents, multithreaded.
 
-    :param agents: the click context.
+    :param click_context: the click context.
     :param agents: list of paths to agent projects.
     :return: exit status
     """
@@ -131,23 +116,14 @@ def _launch_threads(click_context: click.Context, agents: List[Path]) -> int:
         with cd(agent_directory):
             aeas.append(AEABuilder.from_aea_project(".").build())
 
-    threads = [Thread(target=agent.start) for agent in aeas]
-    for t in threads:
-        t.start()
-
+    runner = AEARunner(
+        agents=aeas, mode="threaded", fail_policy=ExecutorExceptionPolicies.log_only
+    )
     try:
-        while sum([t.is_alive() for t in threads]) != 0:
-            # exit when all threads are not alive.
-            # done to avoid block on joins
-            for t in threads:
-                t.join(0.1)
-
+        runner.start(threaded=True)
+        runner.join_thread()  # for some reason on windows and python 3.7/3.7 keyboard interuption exception gets lost so run in threaded mode to catch keyboard interruped
     except KeyboardInterrupt:
         logger.info("Keyboard interrupt detected.")
     finally:
-        for idx, agent in enumerate(aeas):
-            if not agent.is_stopped:
-                agent.stop()
-            threads[idx].join()
-            logger.info("Agent {} has been stopped.".format(agent.name))
-    return 0
+        runner.stop()
+    return runner.num_failed
