@@ -42,51 +42,27 @@ from aea.configurations.base import (
     _get_default_configuration_file_name_from_type,
 )
 from aea.configurations.loader import ConfigLoader
-from aea.crypto.helpers import (
-    IDENTIFIER_TO_KEY_FILES,
-    create_private_key,
-    try_validate_private_key_path,
-)
+from aea.crypto.helpers import verify_or_create_private_keys
 from aea.crypto.ledger_apis import DEFAULT_LEDGER_CONFIGS, LedgerApis
-from aea.crypto.registries import crypto_registry
 from aea.crypto.wallet import Wallet
 
+ROOT = Path(".")
 
-def verify_or_create_private_keys(ctx: Context) -> None:
+
+def verify_or_create_private_keys_ctx(
+    ctx: Context, aea_project_path: Path = ROOT, exit_on_error: bool = True,
+) -> None:
     """
-    Verify or create private keys.
+    Verify or create private keys with ctx provided.
 
     :param ctx: Context
     """
-    path = Path(DEFAULT_AEA_CONFIG_FILE)
-    agent_loader = ConfigLoader("aea-config_schema.json", AgentConfig)
-    fp = path.open(mode="r", encoding="utf-8")
-    aea_conf = agent_loader.load(fp)
-
-    for identifier, _value in aea_conf.private_key_paths.read_all():
-        if identifier not in crypto_registry.supported_ids:
-            ValueError("Unsupported identifier in private key paths.")
-
-    for identifier, private_key_path in IDENTIFIER_TO_KEY_FILES.items():
-        config_private_key_path = aea_conf.private_key_paths.read(identifier)
-        if config_private_key_path is None:
-            create_private_key(identifier)
-            aea_conf.private_key_paths.update(identifier, private_key_path)
-        else:
-            try:
-                try_validate_private_key_path(identifier, private_key_path)
-            except FileNotFoundError:  # pragma: no cover
-                raise click.ClickException(
-                    "File {} for private key {} not found.".format(
-                        repr(private_key_path), identifier,
-                    )
-                )
-
-    # update aea config
-    path = Path(DEFAULT_AEA_CONFIG_FILE)
-    fp = path.open(mode="w", encoding="utf-8")
-    agent_loader.dump(aea_conf, fp)
-    ctx.agent_config = aea_conf
+    try:
+        agent_config = verify_or_create_private_keys(aea_project_path, exit_on_error)
+        if ctx is not None:
+            ctx.agent_config = agent_config
+    except ValueError as e:  # pragma: nocover
+        click.ClickException(str(e))
 
 
 def validate_package_name(package_name: str):
@@ -430,9 +406,8 @@ def try_get_balance(agent_config: AgentConfig, wallet: Wallet, type_: str) -> in
     try:
         if type_ not in DEFAULT_LEDGER_CONFIGS:  # pragma: no cover
             raise ValueError("No ledger api config for {} available.".format(type_))
-        ledger_apis = LedgerApis(DEFAULT_LEDGER_CONFIGS, agent_config.default_ledger)
         address = wallet.addresses[type_]
-        balance = ledger_apis.get_balance(type_, address)
+        balance = LedgerApis.get_balance(type_, address)
         if balance is None:  # pragma: no cover
             raise ValueError("No balance returned!")
         return balance
