@@ -27,7 +27,7 @@ from asyncio.tasks import Task
 from concurrent.futures.thread import ThreadPoolExecutor
 from contextlib import contextmanager
 from pathlib import Path
-from typing import AsyncIterable, IO, List, Optional
+from typing import AsyncIterable, IO, List, Optional, Union
 
 from aea.configurations.base import PublicId
 from aea.connections.base import Connection, ConnectionStates
@@ -44,7 +44,7 @@ DEFAULT_INPUT_FILE_NAME = "./input_file"
 DEFAULT_OUTPUT_FILE_NAME = "./output_file"
 SEPARATOR = b","
 
-PUBLIC_ID = PublicId.from_str("fetchai/stub:0.7.0")
+PUBLIC_ID = PublicId.from_str("fetchai/stub:0.8.0")
 
 
 def _encode(e: Envelope, separator: bytes = SEPARATOR):
@@ -103,9 +103,13 @@ def write_envelope(envelope: Envelope, file_pointer: IO[bytes]) -> None:
     """Write envelope to file."""
     encoded_envelope = _encode(envelope, separator=SEPARATOR)
     logger.debug("write {}: to {}".format(encoded_envelope, file_pointer.name))
+    write_with_lock(file_pointer, encoded_envelope)
 
+
+def write_with_lock(file_pointer: IO[bytes], data: Union[bytes]) -> None:
+    """Write bytes to file protected with file lock."""
     with lock_file(file_pointer):
-        file_pointer.write(encoded_envelope)
+        file_pointer.write(data)
         file_pointer.flush()
 
 
