@@ -18,7 +18,7 @@
 # ------------------------------------------------------------------------------
 
 """
-This module contains an adaptation of click.testing.CliRunner
+This module contains an adaptation of click.testing.CliRunner.
 
 In particular, it fixes an issue in
 CLIRunner.invoke, in the 'finally' clause. More precisely, before reading from
@@ -37,7 +37,7 @@ from click.testing import CliRunner as ClickCliRunner, Result
 
 
 class CliRunner(ClickCliRunner):
-    """Patch of click.testing.CliRunner"""
+    """Patch of click.testing.CliRunner."""
 
     def invoke(
         self,
@@ -49,12 +49,12 @@ class CliRunner(ClickCliRunner):
         color=False,
         **extra
     ):
-        """Patch click.testing.CliRunner.invoke()."""
+        """Call a cli command with click.testing.CliRunner.invoke."""
         exc_info = None
-        with self.isolation(input=input, env=env, color=color) as outstreams:
-            exception = None
-            exit_code = 0
+        exception = None
+        exit_code = 0
 
+        with self.isolation(input=input, env=env, color=color) as outstreams:
             if isinstance(args, string_types):
                 args = shlex.split(args)
 
@@ -68,10 +68,10 @@ class CliRunner(ClickCliRunner):
             except SystemExit as e:
                 exc_info = sys.exc_info()
                 exit_code = e.code
-                if exit_code is None:
+                if exit_code is None:  # pragma: nocover
                     exit_code = 0
 
-                if exit_code != 0:
+                if exit_code != 0:  # pragma: nocover
                     exception = e
 
                 if not isinstance(exit_code, int):
