@@ -34,7 +34,7 @@ from filecmp import dircmp
 from io import TextIOWrapper
 from pathlib import Path
 from threading import Thread
-from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Set, Tuple, Union
 
 import pytest
 
@@ -48,7 +48,7 @@ from aea.connections.stub.connection import (
     DEFAULT_INPUT_FILE_NAME,
     DEFAULT_OUTPUT_FILE_NAME,
 )
-from aea.helpers.base import cd, sigint_crossplatform
+from aea.helpers.base import cd, send_control_c, win_popen_kwargs
 from aea.mail.base import Envelope
 from aea.test_tools.click_testing import CliRunner, Result
 from aea.test_tools.constants import DEFAULT_AUTHOR
@@ -89,6 +89,8 @@ class BaseAEATestCase(ABC):
     stdout: Dict[int, str]  # dict of process.pid: string stdout
     stderr: Dict[int, str]  # dict of process.pid: string stderr
     _is_teardown_class_called: bool = False
+    capture_log: bool = False
+    cli_log_options: List[str] = []
 
     @classmethod
     def set_agent_context(cls, agent_name: str):
@@ -179,12 +181,17 @@ class BaseAEATestCase(ABC):
 
         :return: subprocess object.
         """
-        process = subprocess.Popen(  # nosec
-            [sys.executable, *args],
+        kwargs = dict(
             stdout=subprocess.PIPE,
+            stdin=subprocess.PIPE,
             env=os.environ.copy(),
             cwd=cwd,
         )
+        kwargs.update(win_popen_kwargs())
+
+        process = subprocess.Popen(  # type: ignore # nosec # mypy fails on **kwargs
+            [sys.executable, *args], **kwargs,
+        )
         cls.subprocesses.append(process)
         return process
 
@@ -273,7 +280,13 @@ class BaseAEATestCase(ABC):
                 if content2[key] == value:
                     content1.pop(key)
                     content2.pop(key)
-            allowed_diff_keys = ["aea_version", "author", "description", "version"]
+            allowed_diff_keys = [
+                "aea_version",
+                "author",
+                "description",
+                "version",
+                "registry_path",
+            ]
             result = all([key in allowed_diff_keys for key in content1.keys()])
             result = result and all(
                 [key in allowed_diff_keys for key in content2.keys()]
@@ -336,12 +349,7 @@ class BaseAEATestCase(ABC):
 
         :return: subprocess object.
         """
-        process = cls._run_python_subprocess(
-            "-m", "aea.cli", "run", *args, cwd=cls._get_cwd()
-        )
-        cls._start_output_read_thread(process)
-        cls._start_error_read_thread(process)
-        return process
+        return cls._start_cli_process("run", *args)
 
     @classmethod
     def run_interaction(cls) -> subprocess.Popen:
@@ -352,10 +360,20 @@ class BaseAEATestCase(ABC):
 
         :param args: CLI args
 
+        :return: subprocess object.
+        """
+        return cls._start_cli_process("interact")
+
+    @classmethod
+    def _start_cli_process(cls, *args: str) -> subprocess.Popen:
+        """
+        Start cli subprocess with args specified.
+
+        :param args: CLI args
         :return: subprocess object.
         """
         process = cls._run_python_subprocess(
-            "-m", "aea.cli", "interact", cwd=cls._get_cwd()
+            "-m", "aea.cli", *cls.cli_log_options, *args, cwd=cls._get_cwd()
         )
         cls._start_output_read_thread(process)
         cls._start_error_read_thread(process)
@@ -374,13 +392,15 @@ class BaseAEATestCase(ABC):
         Run from agent's directory.
 
         :param subprocesses: the subprocesses running the agents
-        :param signal: the signal for interuption
-        :param timeout: the timeout for interuption
+        :param signal: the signal for interruption
+        :param timeout: the timeout for interruption
         """
         if not subprocesses:
             subprocesses = tuple(cls.subprocesses)
         for process in subprocesses:
-            sigint_crossplatform(process)
+            process.poll()
+            if process.returncode is None:  # stop only pending processes
+                send_control_c(process)
         for process in subprocesses:
             process.wait(timeout=timeout)
 
@@ -491,7 +511,7 @@ class BaseAEATestCase(ABC):
         :return: Result
         """
         cli_args = ["generate-key", ledger_api_id]
-        if private_key_file is not None:
+        if private_key_file is not None:  # pragma: nocover
             cli_args.append(private_key_file)
         return cls.run_cli_command(*cli_args, cwd=cls._get_cwd())
 
@@ -616,14 +636,23 @@ class BaseAEATestCase(ABC):
     @classmethod
     def _read_out(cls, process: subprocess.Popen):  # pragma: nocover # runs in thread!
         for line in TextIOWrapper(process.stdout, encoding="utf-8"):
+            cls._log_capture("stdout", process.pid, line)
             cls.stdout[process.pid] += line
 
     @classmethod
     def _read_err(cls, process: subprocess.Popen):  # pragma: nocover # runs in thread!
         if process.stderr is not None:
             for line in TextIOWrapper(process.stderr, encoding="utf-8"):
+                cls._log_capture("stderr", process.pid, line)
                 cls.stderr[process.pid] += line
 
+    @classmethod
+    def _log_capture(cls, name, pid, line):  # pragma: nocover
+        if not cls.capture_log:
+            return
+        sys.stdout.write(f"[{pid}]{name}>{line}")
+        sys.stdout.flush()
+
     @classmethod
     def _start_output_read_thread(cls, process: subprocess.Popen) -> None:
         """
@@ -656,6 +685,10 @@ class BaseAEATestCase(ABC):
     @classmethod
     def send_envelope_to_agent(cls, envelope: Envelope, agent: str):
         """Send an envelope to an agent, using the stub connection."""
+        # check added cause sometimes fails on win with permission error
+        dir_path = Path(cls.t / agent)
+        assert dir_path.exists()
+        assert dir_path.is_dir()
         write_envelope_to_file(envelope, str(cls.t / agent / DEFAULT_INPUT_FILE_NAME))
 
     @classmethod
@@ -667,7 +700,7 @@ class BaseAEATestCase(ABC):
     def missing_from_output(
         cls,
         process: subprocess.Popen,
-        strings: Tuple[str],
+        strings: Sequence[str],
         timeout: int = DEFAULT_PROCESS_TIMEOUT,
         period: int = 1,
         is_terminating: bool = True,
