@@ -16,24 +16,26 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-
 """This module contains base classes for the ledger API connection."""
 import asyncio
+import copy
+import logging
 from abc import ABC, abstractmethod
 from asyncio import Task
 from concurrent.futures._base import Executor
+from logging import Logger
 from typing import Any, Callable, Dict, Optional
 
 from aea.configurations.base import PublicId
-from aea.connections.base import ConnectionStatus
 from aea.crypto.base import LedgerApi
 from aea.crypto.registries import Registry, ledger_apis_registry
+from aea.helpers.async_utils import AsyncState
 from aea.helpers.dialogue.base import Dialogue, Dialogues
 from aea.mail.base import Envelope
 from aea.protocols.base import Message
 
 
-CONNECTION_ID = PublicId.from_str("fetchai/ledger:0.2.0")
+CONNECTION_ID = PublicId.from_str("fetchai/ledger:0.3.0")
 
 
 class RequestDispatcher(ABC):
@@ -44,10 +46,11 @@ class RequestDispatcher(ABC):
 
     def __init__(
         self,
-        connection_status: ConnectionStatus,
+        connection_state: AsyncState,
         loop: Optional[asyncio.AbstractEventLoop] = None,
         executor: Optional[Executor] = None,
         api_configs: Optional[Dict[str, Dict[str, str]]] = None,
+        logger: Optional[Logger] = None,
     ):
         """
         Initialize the request dispatcher.
@@ -55,10 +58,17 @@ class RequestDispatcher(ABC):
         :param loop: the asyncio loop.
         :param executor: an executor.
         """
-        self.connection_status = connection_status
+        self.connection_state = connection_state
         self.loop = loop if loop is not None else asyncio.get_event_loop()
         self.executor = executor
         self._api_configs = api_configs
+        self.logger = (
+            logger
+            if logger is not None
+            else logging.getLogger(
+                "aea.packages.fetchai.connections.ledger.contract_dispatcher"
+            )
+        )
 
     def api_config(self, ledger_id: str) -> Dict[str, str]:
         """Get api config."""
@@ -97,10 +107,12 @@ class RequestDispatcher(ABC):
         :return: an awaitable.
         """
         assert isinstance(envelope.message, Message)
-        message = envelope.message
+        message_original = envelope.message
+        message = copy.copy(message_original)
         ledger_id = self.get_ledger_id(message)
         api = self.ledger_api_registry.make(ledger_id, **self.api_config(ledger_id))
         message.is_incoming = True
+        message.counterparty = message_original.sender
         dialogue = self.dialogues.update(message)
         assert dialogue is not None, "No dialogue created."
         performative = message.performative
