@@ -45,7 +45,7 @@ MESSAGE_ID = 1
 RESPONSE_TARGET = MESSAGE_ID
 RESPONSE_MESSAGE_ID = MESSAGE_ID + 1
 STUB_DIALOGUE_ID = 0
-PUBLIC_ID = PublicId.from_str("fetchai/local:0.5.0")
+PUBLIC_ID = PublicId.from_str("fetchai/local:0.6.0")
 
 
 class LocalNode:
@@ -62,7 +62,7 @@ class LocalNode:
         self.services = defaultdict(lambda: [])  # type: Dict[str, List[Description]]
         self._lock = asyncio.Lock()
         self._loop = loop if loop is not None else asyncio.new_event_loop()
-        self._thread = Thread(target=self._run_loop)
+        self._thread = Thread(target=self._run_loop, daemon=True)
 
         self._in_queue = asyncio.Queue(loop=self._loop)  # type: asyncio.Queue
         self._out_queues = {}  # type: Dict[str, asyncio.Queue]
@@ -277,33 +277,34 @@ class LocalNode:
         :param dialogue: the dialogue.
         :return: None
         """
-        query = oef_search_msg.query
-        result = []  # type: List[str]
-        if query.model is None:
-            result = list(set(self.services.keys()))
-        else:
-            for agent_address, descriptions in self.services.items():
-                for description in descriptions:
-                    if description.data_model == query.model:
-                        result.append(agent_address)
+        async with self._lock:
+            query = oef_search_msg.query
+            result = []  # type: List[str]
+            if query.model is None:
+                result = list(set(self.services.keys()))
+            else:
+                for agent_address, descriptions in self.services.items():
+                    for description in descriptions:
+                        if description.data_model == query.model:
+                            result.append(agent_address)
 
-        msg = OefSearchMessage(
-            performative=OefSearchMessage.Performative.SEARCH_RESULT,
-            target=oef_search_msg.message_id,
-            dialogue_reference=dialogue.dialogue_label.dialogue_reference,
-            message_id=oef_search_msg.message_id + 1,
-            agents=tuple(sorted(set(result))),
-        )
-        msg.counterparty = oef_search_msg.sender
-        assert dialogue.update(msg)
+            msg = OefSearchMessage(
+                performative=OefSearchMessage.Performative.SEARCH_RESULT,
+                target=oef_search_msg.message_id,
+                dialogue_reference=dialogue.dialogue_label.dialogue_reference,
+                message_id=oef_search_msg.message_id + 1,
+                agents=tuple(sorted(set(result))),
+            )
+            msg.counterparty = oef_search_msg.sender
+            assert dialogue.update(msg)
 
-        envelope = Envelope(
-            to=msg.counterparty,
-            sender=msg.sender,
-            protocol_id=msg.protocol_id,
-            message=msg,
-        )
-        await self._send(envelope)
+            envelope = Envelope(
+                to=msg.counterparty,
+                sender=msg.sender,
+                protocol_id=msg.protocol_id,
+                message=msg,
+            )
+            await self._send(envelope)
 
     def _get_message_and_dialogue(
         self, envelope: Envelope
@@ -373,7 +374,7 @@ class OEFLocalConnection(Connection):
         """Connect to the local OEF Node."""
         assert self._local_node is not None, "No local node set!"
         if self.is_connected:
-            return
+            return  # pragma: nocover
         self._state.set(ConnectionStates.connecting)
         self._reader = Queue()
         self._writer = await self._local_node.connect(self.address, self._reader)
@@ -383,7 +384,7 @@ class OEFLocalConnection(Connection):
         """Disconnect from the local OEF Node."""
         assert self._local_node is not None, "No local node set!"
         if self.is_disconnected:
-            return
+            return  # pragma: nocover
         self._state.set(ConnectionStates.disconnecting)
         assert self._reader is not None
         await self._local_node.disconnect(self.address)
