@@ -70,7 +70,9 @@ class GenericStrategy(Model):
 
         self._search_query = kwargs.pop("search_query", DEFAULT_SEARCH_QUERY)
         location = kwargs.pop("location", DEFAULT_LOCATION)
-        self._agent_location = Location(location["longitude"], location["latitude"])
+        self._agent_location = Location(
+            longitude=location["longitude"], latitude=location["latitude"]
+        )
         self._radius = kwargs.pop("search_radius", DEFAULT_SEARCH_RADIUS)
 
         self._max_negotiations = kwargs.pop(
