@@ -57,9 +57,7 @@ class TACHandler(Handler):
         game = cast(Game, self.context.game)
 
         self.context.logger.debug(
-            "[{}]: Handling TAC message. type={}".format(
-                self.context.agent_name, tac_message.performative
-            )
+            "handling TAC message. type={}".format(tac_message.performative)
         )
         if (
             tac_message.performative == TacMessage.Performative.REGISTER
@@ -73,9 +71,7 @@ class TACHandler(Handler):
             self._on_unregister(tac_message)
         else:
             self.context.logger.warning(
-                "[{}]: TAC Message type not recognized or not permitted.".format(
-                    self.context.agent_name
-                )
+                "TAC Message type not recognized or not permitted."
             )
 
     def _on_register(self, message: TacMessage) -> None:
@@ -91,9 +87,7 @@ class TACHandler(Handler):
         agent_name = message.agent_name
         if len(parameters.whitelist) != 0 and agent_name not in parameters.whitelist:
             self.context.logger.warning(
-                "[{}]: Agent name not in whitelist: '{}'".format(
-                    self.context.agent_name, agent_name
-                )
+                "agent name not in whitelist: '{}'".format(agent_name)
             )
             tac_msg = TacMessage(
                 performative=TacMessage.Performative.TAC_ERROR,
@@ -106,8 +100,7 @@ class TACHandler(Handler):
         game = cast(Game, self.context.game)
         if message.counterparty in game.registration.agent_addr_to_name:
             self.context.logger.warning(
-                "[{}]: Agent already registered: '{}'".format(
-                    self.context.agent_name,
+                "agent already registered: '{}'".format(
                     game.registration.agent_addr_to_name[message.counterparty],
                 )
             )
@@ -120,9 +113,7 @@ class TACHandler(Handler):
 
         if agent_name in game.registration.agent_addr_to_name.values():
             self.context.logger.warning(
-                "[{}]: Agent with this name already registered: '{}'".format(
-                    self.context.agent_name, agent_name
-                )
+                "agent with this name already registered: '{}'".format(agent_name)
             )
             tac_msg = TacMessage(
                 performative=TacMessage.Performative.TAC_ERROR,
@@ -131,9 +122,7 @@ class TACHandler(Handler):
             tac_msg.counterparty = message.counterparty
             self.context.outbox.put_message(message=tac_msg)
         game.registration.register_agent(message.counterparty, agent_name)
-        self.context.logger.info(
-            "[{}]: Agent registered: '{}'".format(self.context.agent_name, agent_name)
-        )
+        self.context.logger.info("agent registered: '{}'".format(agent_name))
 
     def _on_unregister(self, message: TacMessage) -> None:
         """
@@ -147,9 +136,7 @@ class TACHandler(Handler):
         game = cast(Game, self.context.game)
         if message.counterparty not in game.registration.agent_addr_to_name:
             self.context.logger.warning(
-                "[{}]: Agent not registered: '{}'".format(
-                    self.context.agent_name, message.counterparty
-                )
+                "agent not registered: '{}'".format(message.counterparty)
             )
             tac_msg = TacMessage(
                 performative=TacMessage.Performative.TAC_ERROR,
@@ -159,8 +146,7 @@ class TACHandler(Handler):
             self.context.outbox.put_message(message=tac_msg)
         else:
             self.context.logger.debug(
-                "[{}]: Agent unregistered: '{}'".format(
-                    self.context.agent_name,
+                "agent unregistered: '{}'".format(
                     game.conf.agent_addr_to_name[message.counterparty],
                 )
             )
@@ -198,16 +184,12 @@ class OEFRegistrationHandler(Handler):
         oef_message = cast(OefSearchMessage, message)
 
         self.context.logger.debug(
-            "[{}]: Handling OEF message. type={}".format(
-                self.context.agent_name, oef_message.performative
-            )
+            "handling OEF message. type={}".format(oef_message.performative)
         )
         if oef_message.performative == OefSearchMessage.Performative.OEF_ERROR:
             self._on_oef_error(oef_message)
         else:
-            self.context.logger.warning(
-                "[{}]: OEF Message type not recognized.".format(self.context.agent_name)
-            )
+            self.context.logger.warning("OEF Message type not recognized.")
 
     def _on_oef_error(self, oef_error: OefSearchMessage) -> None:
         """
@@ -218,10 +200,8 @@ class OEFRegistrationHandler(Handler):
         :return: None
         """
         self.context.logger.warning(
-            "[{}]: Received OEF Search error: dialogue_reference={}, operation={}".format(
-                self.context.agent_name,
-                oef_error.dialogue_reference,
-                oef_error.oef_error_operation,
+            "received OEF Search error: dialogue_reference={}, operation={}".format(
+                oef_error.dialogue_reference, oef_error.oef_error_operation,
             )
         )
 
@@ -256,56 +236,32 @@ class SigningHandler(Handler):
         ledger_api = self.context.ledger_apis.get_api(parameters.ledger)
         if signing_msg_response.dialogue_reference[0] == "contract_deploy":
             game.phase = Phase.CONTRACT_DEPLOYING
-            self.context.logger.info(
-                "[{}]: Sending deployment transaction to the ledger...".format(
-                    self.context.agent_name
-                )
-            )
+            self.context.logger.info("sending deployment transaction to the ledger...")
             tx_signed = signing_msg_response.signed_transaction
             tx_digest = ledger_api.send_signed_transaction(tx_signed=tx_signed)
             if tx_digest is None:
-                self.context.logger.warning(
-                    "[{}]: Sending transaction failed. Aborting!".format(
-                        self.context.agent_name
-                    )
-                )
+                self.context.logger.warning("sending transaction failed. Aborting!")
                 self.context.is_active = False
             else:
                 game.contract_manager.deploy_tx_digest = tx_digest
         elif signing_msg_response.dialogue_reference[0] == "contract_create_batch":
             game.phase = Phase.TOKENS_CREATING
-            self.context.logger.info(
-                "[{}]: Sending creation transaction to the ledger...".format(
-                    self.context.agent_name
-                )
-            )
+            self.context.logger.info("sending creation transaction to the ledger...")
             tx_signed = signing_msg_response.signed_transaction
             tx_digest = ledger_api.send_signed_transaction(tx_signed=tx_signed)
             if tx_digest is None:
-                self.context.logger.warning(
-                    "[{}]: Sending transaction failed. Aborting!".format(
-                        self.context.agent_name
-                    )
-                )
+                self.context.logger.warning("sending transaction failed. Aborting!")
                 self.context.is_active = False
             else:
                 game.contract_manager.create_tokens_tx_digest = tx_digest
         elif signing_msg_response.dialogue_reference[0] == "contract_mint_batch":
             game.phase = Phase.TOKENS_MINTING
-            self.context.logger.info(
-                "[{}]: Sending minting transaction to the ledger...".format(
-                    self.context.agent_name
-                )
-            )
+            self.context.logger.info("sending minting transaction to the ledger...")
             tx_signed = signing_msg_response.signed_transaction
             agent_addr = signing_msg_response.terms.counterparty_address
             tx_digest = ledger_api.send_signed_transaction(tx_signed=tx_signed)
             if tx_digest is None:
-                self.context.logger.warning(
-                    "[{}]: Sending transaction failed. Aborting!".format(
-                        self.context.agent_name
-                    )
-                )
+                self.context.logger.warning("sending transaction failed. Aborting!")
                 self.context.is_active = False
             else:
                 game.contract_manager.set_mint_tokens_tx_digest(agent_addr, tx_digest)
