@@ -151,9 +151,9 @@ def ipfs_hashing(
     # hash again to get outer hash (this time all files):
     # TODO we still need to ignore some files
     #      use ignore patterns somehow
-    # ignore_patterns = configuration.fingerprint_ignore_patterns]
+    # ignore_patterns = configuration.fingerprint_ignore_patterns
     assert configuration.directory is not None
-    result_list = client.add(configuration.directory)
+    result_list = client.add(configuration.directory, recursive=True)
     key = os.path.join(
         configuration.author, package_type.to_plural(), configuration.directory.name,
     )
@@ -511,11 +511,19 @@ def check_hashes(timeout: float = 10.0) -> int:
     return return_code
 
 
+def clean_directory() -> None:
+    """Clean the directory."""
+    clean_command = ["make", "clean"]
+    process = subprocess.Popen(clean_command, stdout=subprocess.PIPE)  # nosec
+    _, _ = process.communicate()
+
+
 if __name__ == "__main__":
     arguments = parse_arguments()
     if arguments.check:
         return_code = check_hashes(arguments.timeout)
     else:
+        clean_directory()
         return_code = update_hashes(arguments.timeout)
 
     sys.exit(return_code)
