@@ -186,8 +186,12 @@ def process_packages(
     is_bumped = False
     for type_ in TYPES:
         for key, value in last_by_type[type_].items():
+            if key == "scaffold":
+                print("Package `{}` of type `{}` is never bumped!".format(key, type_))
+                continue
             if key not in now_by_type[type_]:
                 print("Package `{}` of type `{}` no longer present!".format(key, type_))
+                continue
             if now_by_type[type_][key] == value:
                 print(
                     "Package `{}` of type `{}` has not changed since last release!".format(
@@ -291,7 +295,6 @@ def process_package(type_: str, name: str) -> bool:
 
 def run_once() -> bool:
     """Run the upgrade logic once."""
-    check_if_running_allowed()
     last = get_hashes_from_last_release()
     now = get_hashes_from_current_release()
     last_by_type = split_hashes_by_type(last)
@@ -301,6 +304,12 @@ def run_once() -> bool:
 
 
 if __name__ == "__main__":
+    """
+    First, check all hashes are up to date, exit if not.
+    Then, run the bumping algo, re-hashing upon each bump.
+    """
+    run_hashing()
+    check_if_running_allowed()
     while run_once():
         run_hashing()
     sys.exit(0)
