@@ -28,7 +28,7 @@ from aea.protocols.base import Message
 
 from tests.data.generator.t_protocol.custom_types import DataModel as CustomDataModel
 
-logger = logging.getLogger("packages.fetchai.protocols.t_protocol.message")
+logger = logging.getLogger("aea.packages.fetchai.protocols.t_protocol.message")
 
 DEFAULT_BODY_SIZE = 4
 
@@ -36,7 +36,7 @@ DEFAULT_BODY_SIZE = 4
 class TProtocolMessage(Message):
     """A protocol for testing purposes."""
 
-    protocol_id = ProtocolId("fetchai", "t_protocol", "0.1.0")
+    protocol_id = ProtocolId.from_str("fetchai/t_protocol:0.1.0")
 
     DataModel = CustomDataModel
 
@@ -106,7 +106,7 @@ class TProtocolMessage(Message):
         return cast(int, self.get("message_id"))
 
     @property
-    def performative(self) -> Performative:  # noqa: F821
+    def performative(self) -> Performative:  # type: ignore # noqa: F821
         """Get the performative of the message."""
         assert self.is_set("performative"), "performative is not set."
         return cast(TProtocolMessage.Performative, self.get("performative"))
@@ -135,6 +135,14 @@ class TProtocolMessage(Message):
         assert self.is_set("content_ct"), "'content_ct' content is not set."
         return cast(CustomDataModel, self.get("content_ct"))
 
+    @property
+    def content_dict_bool_bool(self) -> Dict[bool, bool]:
+        """Get the 'content_dict_bool_bool' content from the message."""
+        assert self.is_set(
+            "content_dict_bool_bool"
+        ), "'content_dict_bool_bool' content is not set."
+        return cast(Dict[bool, bool], self.get("content_dict_bool_bool"))
+
     @property
     def content_dict_bool_bytes(self) -> Dict[bool, bytes]:
         """Get the 'content_dict_bool_bytes' content from the message."""
@@ -143,6 +151,86 @@ class TProtocolMessage(Message):
         ), "'content_dict_bool_bytes' content is not set."
         return cast(Dict[bool, bytes], self.get("content_dict_bool_bytes"))
 
+    @property
+    def content_dict_bool_float(self) -> Dict[bool, float]:
+        """Get the 'content_dict_bool_float' content from the message."""
+        assert self.is_set(
+            "content_dict_bool_float"
+        ), "'content_dict_bool_float' content is not set."
+        return cast(Dict[bool, float], self.get("content_dict_bool_float"))
+
+    @property
+    def content_dict_bool_int(self) -> Dict[bool, int]:
+        """Get the 'content_dict_bool_int' content from the message."""
+        assert self.is_set(
+            "content_dict_bool_int"
+        ), "'content_dict_bool_int' content is not set."
+        return cast(Dict[bool, int], self.get("content_dict_bool_int"))
+
+    @property
+    def content_dict_bool_str(self) -> Dict[bool, str]:
+        """Get the 'content_dict_bool_str' content from the message."""
+        assert self.is_set(
+            "content_dict_bool_str"
+        ), "'content_dict_bool_str' content is not set."
+        return cast(Dict[bool, str], self.get("content_dict_bool_str"))
+
+    @property
+    def content_dict_int_bool(self) -> Dict[int, bool]:
+        """Get the 'content_dict_int_bool' content from the message."""
+        assert self.is_set(
+            "content_dict_int_bool"
+        ), "'content_dict_int_bool' content is not set."
+        return cast(Dict[int, bool], self.get("content_dict_int_bool"))
+
+    @property
+    def content_dict_int_bytes(self) -> Dict[int, bytes]:
+        """Get the 'content_dict_int_bytes' content from the message."""
+        assert self.is_set(
+            "content_dict_int_bytes"
+        ), "'content_dict_int_bytes' content is not set."
+        return cast(Dict[int, bytes], self.get("content_dict_int_bytes"))
+
+    @property
+    def content_dict_int_float(self) -> Dict[int, float]:
+        """Get the 'content_dict_int_float' content from the message."""
+        assert self.is_set(
+            "content_dict_int_float"
+        ), "'content_dict_int_float' content is not set."
+        return cast(Dict[int, float], self.get("content_dict_int_float"))
+
+    @property
+    def content_dict_int_int(self) -> Dict[int, int]:
+        """Get the 'content_dict_int_int' content from the message."""
+        assert self.is_set(
+            "content_dict_int_int"
+        ), "'content_dict_int_int' content is not set."
+        return cast(Dict[int, int], self.get("content_dict_int_int"))
+
+    @property
+    def content_dict_int_str(self) -> Dict[int, str]:
+        """Get the 'content_dict_int_str' content from the message."""
+        assert self.is_set(
+            "content_dict_int_str"
+        ), "'content_dict_int_str' content is not set."
+        return cast(Dict[int, str], self.get("content_dict_int_str"))
+
+    @property
+    def content_dict_str_bool(self) -> Dict[str, bool]:
+        """Get the 'content_dict_str_bool' content from the message."""
+        assert self.is_set(
+            "content_dict_str_bool"
+        ), "'content_dict_str_bool' content is not set."
+        return cast(Dict[str, bool], self.get("content_dict_str_bool"))
+
+    @property
+    def content_dict_str_bytes(self) -> Dict[str, bytes]:
+        """Get the 'content_dict_str_bytes' content from the message."""
+        assert self.is_set(
+            "content_dict_str_bytes"
+        ), "'content_dict_str_bytes' content is not set."
+        return cast(Dict[str, bytes], self.get("content_dict_str_bytes"))
+
     @property
     def content_dict_str_float(self) -> Dict[str, float]:
         """Get the 'content_dict_str_float' content from the message."""
@@ -151,6 +239,22 @@ class TProtocolMessage(Message):
         ), "'content_dict_str_float' content is not set."
         return cast(Dict[str, float], self.get("content_dict_str_float"))
 
+    @property
+    def content_dict_str_int(self) -> Dict[str, int]:
+        """Get the 'content_dict_str_int' content from the message."""
+        assert self.is_set(
+            "content_dict_str_int"
+        ), "'content_dict_str_int' content is not set."
+        return cast(Dict[str, int], self.get("content_dict_str_int"))
+
+    @property
+    def content_dict_str_str(self) -> Dict[str, str]:
+        """Get the 'content_dict_str_str' content from the message."""
+        assert self.is_set(
+            "content_dict_str_str"
+        ), "'content_dict_str_str' content is not set."
+        return cast(Dict[str, str], self.get("content_dict_str_str"))
+
     @property
     def content_float(self) -> float:
         """Get the 'content_float' content from the message."""
@@ -220,37 +324,9 @@ class TProtocolMessage(Message):
         return cast(Optional[Tuple[bytes, ...]], self.get("content_o_list_bytes"))
 
     @property
-    def content_o_set_float(self) -> Optional[FrozenSet[float]]:
-        """Get the 'content_o_set_float' content from the message."""
-        return cast(Optional[FrozenSet[float]], self.get("content_o_set_float"))
-
-    @property
-    def content_o_union(
-        self,
-    ) -> Optional[
-        Union[
-            str,
-            Dict[str, int],
-            FrozenSet[int],
-            FrozenSet[bytes],
-            Tuple[bool, ...],
-            Dict[str, float],
-        ]
-    ]:
-        """Get the 'content_o_union' content from the message."""
-        return cast(
-            Optional[
-                Union[
-                    str,
-                    Dict[str, int],
-                    FrozenSet[int],
-                    FrozenSet[bytes],
-                    Tuple[bool, ...],
-                    Dict[str, float],
-                ]
-            ],
-            self.get("content_o_union"),
-        )
+    def content_o_set_int(self) -> Optional[FrozenSet[int]]:
+        """Get the 'content_o_set_int' content from the message."""
+        return cast(Optional[FrozenSet[int]], self.get("content_o_set_int"))
 
     @property
     def content_set_bool(self) -> FrozenSet[bool]:
@@ -511,7 +587,102 @@ class TProtocolMessage(Message):
                     type(element) == str for element in self.content_list_str
                 ), "Invalid type for tuple elements in content 'content_list_str'. Expected 'str'."
             elif self.performative == TProtocolMessage.Performative.PERFORMATIVE_PMT:
-                expected_nb_of_contents = 2
+                expected_nb_of_contents = 15
+                assert (
+                    type(self.content_dict_int_bytes) == dict
+                ), "Invalid type for content 'content_dict_int_bytes'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_int_bytes)
+                )
+                for (
+                    key_of_content_dict_int_bytes,
+                    value_of_content_dict_int_bytes,
+                ) in self.content_dict_int_bytes.items():
+                    assert (
+                        type(key_of_content_dict_int_bytes) == int
+                    ), "Invalid type for dictionary keys in content 'content_dict_int_bytes'. Expected 'int'. Found '{}'.".format(
+                        type(key_of_content_dict_int_bytes)
+                    )
+                    assert (
+                        type(value_of_content_dict_int_bytes) == bytes
+                    ), "Invalid type for dictionary values in content 'content_dict_int_bytes'. Expected 'bytes'. Found '{}'.".format(
+                        type(value_of_content_dict_int_bytes)
+                    )
+                assert (
+                    type(self.content_dict_int_int) == dict
+                ), "Invalid type for content 'content_dict_int_int'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_int_int)
+                )
+                for (
+                    key_of_content_dict_int_int,
+                    value_of_content_dict_int_int,
+                ) in self.content_dict_int_int.items():
+                    assert (
+                        type(key_of_content_dict_int_int) == int
+                    ), "Invalid type for dictionary keys in content 'content_dict_int_int'. Expected 'int'. Found '{}'.".format(
+                        type(key_of_content_dict_int_int)
+                    )
+                    assert (
+                        type(value_of_content_dict_int_int) == int
+                    ), "Invalid type for dictionary values in content 'content_dict_int_int'. Expected 'int'. Found '{}'.".format(
+                        type(value_of_content_dict_int_int)
+                    )
+                assert (
+                    type(self.content_dict_int_float) == dict
+                ), "Invalid type for content 'content_dict_int_float'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_int_float)
+                )
+                for (
+                    key_of_content_dict_int_float,
+                    value_of_content_dict_int_float,
+                ) in self.content_dict_int_float.items():
+                    assert (
+                        type(key_of_content_dict_int_float) == int
+                    ), "Invalid type for dictionary keys in content 'content_dict_int_float'. Expected 'int'. Found '{}'.".format(
+                        type(key_of_content_dict_int_float)
+                    )
+                    assert (
+                        type(value_of_content_dict_int_float) == float
+                    ), "Invalid type for dictionary values in content 'content_dict_int_float'. Expected 'float'. Found '{}'.".format(
+                        type(value_of_content_dict_int_float)
+                    )
+                assert (
+                    type(self.content_dict_int_bool) == dict
+                ), "Invalid type for content 'content_dict_int_bool'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_int_bool)
+                )
+                for (
+                    key_of_content_dict_int_bool,
+                    value_of_content_dict_int_bool,
+                ) in self.content_dict_int_bool.items():
+                    assert (
+                        type(key_of_content_dict_int_bool) == int
+                    ), "Invalid type for dictionary keys in content 'content_dict_int_bool'. Expected 'int'. Found '{}'.".format(
+                        type(key_of_content_dict_int_bool)
+                    )
+                    assert (
+                        type(value_of_content_dict_int_bool) == bool
+                    ), "Invalid type for dictionary values in content 'content_dict_int_bool'. Expected 'bool'. Found '{}'.".format(
+                        type(value_of_content_dict_int_bool)
+                    )
+                assert (
+                    type(self.content_dict_int_str) == dict
+                ), "Invalid type for content 'content_dict_int_str'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_int_str)
+                )
+                for (
+                    key_of_content_dict_int_str,
+                    value_of_content_dict_int_str,
+                ) in self.content_dict_int_str.items():
+                    assert (
+                        type(key_of_content_dict_int_str) == int
+                    ), "Invalid type for dictionary keys in content 'content_dict_int_str'. Expected 'int'. Found '{}'.".format(
+                        type(key_of_content_dict_int_str)
+                    )
+                    assert (
+                        type(value_of_content_dict_int_str) == str
+                    ), "Invalid type for dictionary values in content 'content_dict_int_str'. Expected 'str'. Found '{}'.".format(
+                        type(value_of_content_dict_int_str)
+                    )
                 assert (
                     type(self.content_dict_bool_bytes) == dict
                 ), "Invalid type for content 'content_dict_bool_bytes'. Expected 'dict'. Found '{}'.".format(
@@ -531,6 +702,120 @@ class TProtocolMessage(Message):
                     ), "Invalid type for dictionary values in content 'content_dict_bool_bytes'. Expected 'bytes'. Found '{}'.".format(
                         type(value_of_content_dict_bool_bytes)
                     )
+                assert (
+                    type(self.content_dict_bool_int) == dict
+                ), "Invalid type for content 'content_dict_bool_int'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_bool_int)
+                )
+                for (
+                    key_of_content_dict_bool_int,
+                    value_of_content_dict_bool_int,
+                ) in self.content_dict_bool_int.items():
+                    assert (
+                        type(key_of_content_dict_bool_int) == bool
+                    ), "Invalid type for dictionary keys in content 'content_dict_bool_int'. Expected 'bool'. Found '{}'.".format(
+                        type(key_of_content_dict_bool_int)
+                    )
+                    assert (
+                        type(value_of_content_dict_bool_int) == int
+                    ), "Invalid type for dictionary values in content 'content_dict_bool_int'. Expected 'int'. Found '{}'.".format(
+                        type(value_of_content_dict_bool_int)
+                    )
+                assert (
+                    type(self.content_dict_bool_float) == dict
+                ), "Invalid type for content 'content_dict_bool_float'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_bool_float)
+                )
+                for (
+                    key_of_content_dict_bool_float,
+                    value_of_content_dict_bool_float,
+                ) in self.content_dict_bool_float.items():
+                    assert (
+                        type(key_of_content_dict_bool_float) == bool
+                    ), "Invalid type for dictionary keys in content 'content_dict_bool_float'. Expected 'bool'. Found '{}'.".format(
+                        type(key_of_content_dict_bool_float)
+                    )
+                    assert (
+                        type(value_of_content_dict_bool_float) == float
+                    ), "Invalid type for dictionary values in content 'content_dict_bool_float'. Expected 'float'. Found '{}'.".format(
+                        type(value_of_content_dict_bool_float)
+                    )
+                assert (
+                    type(self.content_dict_bool_bool) == dict
+                ), "Invalid type for content 'content_dict_bool_bool'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_bool_bool)
+                )
+                for (
+                    key_of_content_dict_bool_bool,
+                    value_of_content_dict_bool_bool,
+                ) in self.content_dict_bool_bool.items():
+                    assert (
+                        type(key_of_content_dict_bool_bool) == bool
+                    ), "Invalid type for dictionary keys in content 'content_dict_bool_bool'. Expected 'bool'. Found '{}'.".format(
+                        type(key_of_content_dict_bool_bool)
+                    )
+                    assert (
+                        type(value_of_content_dict_bool_bool) == bool
+                    ), "Invalid type for dictionary values in content 'content_dict_bool_bool'. Expected 'bool'. Found '{}'.".format(
+                        type(value_of_content_dict_bool_bool)
+                    )
+                assert (
+                    type(self.content_dict_bool_str) == dict
+                ), "Invalid type for content 'content_dict_bool_str'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_bool_str)
+                )
+                for (
+                    key_of_content_dict_bool_str,
+                    value_of_content_dict_bool_str,
+                ) in self.content_dict_bool_str.items():
+                    assert (
+                        type(key_of_content_dict_bool_str) == bool
+                    ), "Invalid type for dictionary keys in content 'content_dict_bool_str'. Expected 'bool'. Found '{}'.".format(
+                        type(key_of_content_dict_bool_str)
+                    )
+                    assert (
+                        type(value_of_content_dict_bool_str) == str
+                    ), "Invalid type for dictionary values in content 'content_dict_bool_str'. Expected 'str'. Found '{}'.".format(
+                        type(value_of_content_dict_bool_str)
+                    )
+                assert (
+                    type(self.content_dict_str_bytes) == dict
+                ), "Invalid type for content 'content_dict_str_bytes'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_str_bytes)
+                )
+                for (
+                    key_of_content_dict_str_bytes,
+                    value_of_content_dict_str_bytes,
+                ) in self.content_dict_str_bytes.items():
+                    assert (
+                        type(key_of_content_dict_str_bytes) == str
+                    ), "Invalid type for dictionary keys in content 'content_dict_str_bytes'. Expected 'str'. Found '{}'.".format(
+                        type(key_of_content_dict_str_bytes)
+                    )
+                    assert (
+                        type(value_of_content_dict_str_bytes) == bytes
+                    ), "Invalid type for dictionary values in content 'content_dict_str_bytes'. Expected 'bytes'. Found '{}'.".format(
+                        type(value_of_content_dict_str_bytes)
+                    )
+                assert (
+                    type(self.content_dict_str_int) == dict
+                ), "Invalid type for content 'content_dict_str_int'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_str_int)
+                )
+                for (
+                    key_of_content_dict_str_int,
+                    value_of_content_dict_str_int,
+                ) in self.content_dict_str_int.items():
+                    assert (
+                        type(key_of_content_dict_str_int) == str
+                    ), "Invalid type for dictionary keys in content 'content_dict_str_int'. Expected 'str'. Found '{}'.".format(
+                        type(key_of_content_dict_str_int)
+                    )
+                    assert (
+                        type(value_of_content_dict_str_int) == int
+                    ), "Invalid type for dictionary values in content 'content_dict_str_int'. Expected 'int'. Found '{}'.".format(
+                        type(value_of_content_dict_str_int)
+                    )
                 assert (
                     type(self.content_dict_str_float) == dict
                 ), "Invalid type for content 'content_dict_str_float'. Expected 'dict'. Found '{}'.".format(
@@ -550,6 +835,44 @@ class TProtocolMessage(Message):
                     ), "Invalid type for dictionary values in content 'content_dict_str_float'. Expected 'float'. Found '{}'.".format(
                         type(value_of_content_dict_str_float)
                     )
+                assert (
+                    type(self.content_dict_str_bool) == dict
+                ), "Invalid type for content 'content_dict_str_bool'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_str_bool)
+                )
+                for (
+                    key_of_content_dict_str_bool,
+                    value_of_content_dict_str_bool,
+                ) in self.content_dict_str_bool.items():
+                    assert (
+                        type(key_of_content_dict_str_bool) == str
+                    ), "Invalid type for dictionary keys in content 'content_dict_str_bool'. Expected 'str'. Found '{}'.".format(
+                        type(key_of_content_dict_str_bool)
+                    )
+                    assert (
+                        type(value_of_content_dict_str_bool) == bool
+                    ), "Invalid type for dictionary values in content 'content_dict_str_bool'. Expected 'bool'. Found '{}'.".format(
+                        type(value_of_content_dict_str_bool)
+                    )
+                assert (
+                    type(self.content_dict_str_str) == dict
+                ), "Invalid type for content 'content_dict_str_str'. Expected 'dict'. Found '{}'.".format(
+                    type(self.content_dict_str_str)
+                )
+                for (
+                    key_of_content_dict_str_str,
+                    value_of_content_dict_str_str,
+                ) in self.content_dict_str_str.items():
+                    assert (
+                        type(key_of_content_dict_str_str) == str
+                    ), "Invalid type for dictionary keys in content 'content_dict_str_str'. Expected 'str'. Found '{}'.".format(
+                        type(key_of_content_dict_str_str)
+                    )
+                    assert (
+                        type(value_of_content_dict_str_str) == str
+                    ), "Invalid type for dictionary values in content 'content_dict_str_str'. Expected 'str'. Found '{}'.".format(
+                        type(value_of_content_dict_str_str)
+                    )
             elif self.performative == TProtocolMessage.Performative.PERFORMATIVE_MT:
                 expected_nb_of_contents = 2
                 assert (
@@ -642,19 +965,17 @@ class TProtocolMessage(Message):
                     ), "Invalid type for content 'content_o_bool'. Expected 'bool'. Found '{}'.".format(
                         type(content_o_bool)
                     )
-                if self.is_set("content_o_set_float"):
+                if self.is_set("content_o_set_int"):
                     expected_nb_of_contents += 1
-                    content_o_set_float = cast(
-                        FrozenSet[float], self.content_o_set_float
-                    )
+                    content_o_set_int = cast(FrozenSet[int], self.content_o_set_int)
                     assert (
-                        type(content_o_set_float) == frozenset
-                    ), "Invalid type for content 'content_o_set_float'. Expected 'frozenset'. Found '{}'.".format(
-                        type(content_o_set_float)
+                        type(content_o_set_int) == frozenset
+                    ), "Invalid type for content 'content_o_set_int'. Expected 'frozenset'. Found '{}'.".format(
+                        type(content_o_set_int)
                     )
                     assert all(
-                        type(element) == float for element in content_o_set_float
-                    ), "Invalid type for frozenset elements in content 'content_o_set_float'. Expected 'float'."
+                        type(element) == int for element in content_o_set_int
+                    ), "Invalid type for frozenset elements in content 'content_o_set_int'. Expected 'int'."
                 if self.is_set("content_o_list_bytes"):
                     expected_nb_of_contents += 1
                     content_o_list_bytes = cast(
@@ -692,46 +1013,6 @@ class TProtocolMessage(Message):
                         ), "Invalid type for dictionary values in content 'content_o_dict_str_int'. Expected 'int'. Found '{}'.".format(
                             type(value_of_content_o_dict_str_int)
                         )
-                if self.is_set("content_o_union"):
-                    expected_nb_of_contents += 1
-                    content_o_union = cast(
-                        Union[
-                            str,
-                            Dict[str, int],
-                            FrozenSet[int],
-                            FrozenSet[bytes],
-                            Tuple[bool, ...],
-                            Dict[str, float],
-                        ],
-                        self.content_o_union,
-                    )
-                    assert (
-                        type(content_o_union) == dict
-                        or type(content_o_union) == frozenset
-                        or type(content_o_union) == str
-                        or type(content_o_union) == tuple
-                    ), "Invalid type for content 'content_o_union'. Expected either of '['dict', 'frozenset', 'str', 'tuple']'. Found '{}'.".format(
-                        type(content_o_union)
-                    )
-                    if type(content_o_union) == frozenset:
-                        assert all(
-                            type(element) == bytes for element in content_o_union
-                        ) or all(
-                            type(element) == int for element in content_o_union
-                        ), "Invalid type for frozenset elements in content 'content_o_union'. Expected either 'bytes' or 'int'."
-                    if type(content_o_union) == tuple:
-                        assert all(
-                            type(element) == bool for element in content_o_union
-                        ), "Invalid type for tuple elements in content 'content_o_union'. Expected 'bool'."
-                    if type(content_o_union) == dict:
-                        for (
-                            key_of_content_o_union,
-                            value_of_content_o_union,
-                        ) in content_o_union.items():
-                            assert (
-                                type(key_of_content_o_union) == str
-                                and type(value_of_content_o_union) == float
-                            ), "Invalid type for dictionary key, value in content 'content_o_union'. Expected 'str', 'float'."
             elif (
                 self.performative
                 == TProtocolMessage.Performative.PERFORMATIVE_EMPTY_CONTENTS
