@@ -16,6 +16,8 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
+
+
 """This module contains tests for aea/aea_builder.py."""
 import os
 import re
@@ -40,25 +42,25 @@ from aea.configurations.base import (
 from aea.configurations.constants import DEFAULT_LEDGER, DEFAULT_PRIVATE_KEY_FILE
 from aea.contracts.base import Contract
 from aea.exceptions import AEAException
+from aea.helpers.base import cd
 from aea.helpers.exception_policy import ExceptionPolicyEnum
 from aea.protocols.base import Protocol
 from aea.protocols.default import DefaultMessage
 from aea.registries.resources import Resources
 from aea.skills.base import Skill
+from aea.test_tools.test_cases import AEATestCaseEmpty
 
 from tests.conftest import (
     CUR_PATH,
-    FETCHAI_PRIVATE_KEY_PATH,
+    DEFAULT_PRIVATE_KEY_PATH,
     ROOT_DIR,
     _make_dummy_connection,
-    skip_test_windows,
 )
 
 dummy_skill_path = os.path.join(CUR_PATH, "data", "dummy_skill")
 contract_path = os.path.join(ROOT_DIR, "packages", "fetchai", "contracts", "erc1155")
 
 
-@skip_test_windows
 def test_default_timeout_for_agent():
     """Tests agents loop sleep timeout set by AEABuilder.DEFAULT_AGENT_LOOP_TIMEOUT."""
     agent_name = "MyAgent"
@@ -205,7 +207,7 @@ def test_multiple_builds_with_private_keys():
     """Test multiple calls to the 'build()' method when adding custom private keys."""
     builder = AEABuilder()
     builder.set_name("aea_1")
-    builder.add_private_key(DEFAULT_LEDGER, FETCHAI_PRIVATE_KEY_PATH)
+    builder.add_private_key(DEFAULT_LEDGER, DEFAULT_PRIVATE_KEY_PATH)
 
     # the first call works
     aea_1 = builder.build()
@@ -218,7 +220,7 @@ def test_multiple_builds_with_private_keys():
     # after reset, it works
     builder.reset()
     builder.set_name("aea_1")
-    builder.add_private_key(DEFAULT_LEDGER, FETCHAI_PRIVATE_KEY_PATH)
+    builder.add_private_key(DEFAULT_LEDGER, DEFAULT_PRIVATE_KEY_PATH)
     aea_2 = builder.build()
     assert isinstance(aea_2, AEA)
 
@@ -512,3 +514,32 @@ def test_find_import_order():
                 Path(os.path.join(CUR_PATH, "data", "dummy_aea")),
                 True,
             )
+
+
+def test__build_identity_from_wallet():
+    """Test AEABuilder._build_identity_from_wallet."""
+    builder = AEABuilder()
+    builder.set_name("aea_1")
+    builder.add_private_key("fetchai")
+
+    wallet = Mock()
+    wallet.addresses = {}
+    with pytest.raises(ValueError):
+        builder._build_identity_from_wallet(wallet)
+
+    wallet.addresses = {builder._default_ledger: "addr1"}
+    builder._build_identity_from_wallet(wallet)
+
+    wallet.addresses = {builder._default_ledger: "addr1", "fetchai": "addr2"}
+    builder._build_identity_from_wallet(wallet)
+
+
+class TestFromAEAProject(AEATestCaseEmpty):
+    """Test builder set from project dir."""
+
+    def test_from_project(self):
+        """Test builder set from project dir."""
+        builder = AEABuilder.from_aea_project(Path(self._get_cwd()))
+        with cd(self._get_cwd()):
+            aea = builder.build()
+        assert aea.name == self.agent_name
