@@ -53,7 +53,6 @@ from tests.conftest import (
     CONFIGURATION_SCHEMA_DIR,
     CliRunner,
     ROOT_DIR,
-    skip_test_windows,
 )
 
 
@@ -357,8 +356,6 @@ class TestCreateFailsWhenConfigFileIsNotCompliant:
         """Test that the error code is equal to 1 (i.e. catchall for general errors)."""
         assert self.result.exit_code == 1
 
-    # TODO fix this on Windows
-    @skip_test_windows
     def test_agent_folder_is_not_created(self):
         """Test that the agent folder is removed."""
         assert not Path(self.agent_name).exists()
@@ -405,8 +402,6 @@ class TestCreateFailsWhenExceptionOccurs:
         """Test that the error code is equal to 1 (i.e. catchall for general errors)."""
         assert self.result.exit_code == 1
 
-    # TODO fix this on Windows
-    @skip_test_windows
     def test_agent_folder_is_not_created(self):
         """Test that the agent folder is removed."""
         assert not Path(self.agent_name).exists()
