@@ -21,7 +21,6 @@
 """This test module contains the tests for the `aea run` sub-command."""
 import os
 import shutil
-import subprocess  # nosec
 import sys
 import tempfile
 import time
@@ -46,16 +45,11 @@ from aea.configurations.base import (
 from aea.configurations.constants import DEFAULT_CONNECTION
 from aea.crypto.helpers import FETCHAI_PRIVATE_KEY_FILE
 from aea.exceptions import AEAPackageLoadingError
-from aea.helpers.base import sigint_crossplatform
 
 from tests.common.pexpect_popen import PexpectWrapper
 from tests.conftest import AUTHOR, CLI_LOG_OPTION, CliRunner, MAX_FLAKY_RERUNS, ROOT_DIR
 
 
-if sys.platform.startswith("win"):
-    pytest.skip("skipping tests on Windows", allow_module_level=True)
-
-
 @pytest.mark.flaky(reruns=MAX_FLAKY_RERUNS)
 def test_run():
     """Test that the command 'aea run' works as expected."""
@@ -79,7 +73,7 @@ def test_run():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.6.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
     )
     assert result.exit_code == 0
 
@@ -90,29 +84,29 @@ def test_run():
             "config",
             "set",
             "agent.default_connection",
-            "fetchai/http_client:0.6.0",
+            "fetchai/http_client:0.7.0",
         ],
     )
     assert result.exit_code == 0
 
     try:
-        process = subprocess.Popen(  # nosec
+        process = PexpectWrapper(  # nosec
             [sys.executable, "-m", "aea.cli", "run"],
-            stdout=subprocess.PIPE,
             env=os.environ.copy(),
+            maxread=10000,
+            encoding="utf-8",
+            logfile=sys.stdout,
         )
 
-        time.sleep(10.0)
-        sigint_crossplatform(process)
-        process.wait(timeout=20)
+        process.expect("Start processing messages", timeout=10)
+        process.control_c()
+        process.wait_to_complete(10)
 
         assert process.returncode == 0
 
     finally:
-        poll = process.poll()
-        if poll is None:
-            process.terminate()
-            process.wait(2)
+        process.terminate()
+        process.wait_to_complete(10)
 
         os.chdir(cwd)
         try:
@@ -143,23 +137,23 @@ def test_run_with_default_connection():
     os.chdir(Path(t, agent_name))
 
     try:
-        process = subprocess.Popen(  # nosec
+        process = PexpectWrapper(  # nosec
             [sys.executable, "-m", "aea.cli", "run"],
-            stdout=subprocess.PIPE,
             env=os.environ.copy(),
+            maxread=10000,
+            encoding="utf-8",
+            logfile=sys.stdout,
         )
 
-        time.sleep(10.0)
-        sigint_crossplatform(process)
-        process.wait(timeout=20)
+        process.expect("Start processing messages", timeout=10)
+        process.control_c()
+        process.wait_to_complete(10)
 
         assert process.returncode == 0
 
     finally:
-        poll = process.poll()
-        if poll is None:
-            process.terminate()
-            process.wait(2)
+        process.terminate()
+        process.wait_to_complete(10)
 
         os.chdir(cwd)
         try:
@@ -171,9 +165,9 @@ def test_run_with_default_connection():
 @pytest.mark.parametrize(
     argnames=["connection_ids"],
     argvalues=[
-        ["fetchai/http_client:0.6.0,{}".format(str(DEFAULT_CONNECTION))],
-        ["'fetchai/http_client:0.6.0, {}'".format(str(DEFAULT_CONNECTION))],
-        ["fetchai/http_client:0.6.0,,{},".format(str(DEFAULT_CONNECTION))],
+        ["fetchai/http_client:0.7.0,{}".format(str(DEFAULT_CONNECTION))],
+        ["'fetchai/http_client:0.7.0, {}'".format(str(DEFAULT_CONNECTION))],
+        ["fetchai/http_client:0.7.0,,{},".format(str(DEFAULT_CONNECTION))],
     ],
 )
 def test_run_multiple_connections(connection_ids):
@@ -198,7 +192,7 @@ def test_run_multiple_connections(connection_ids):
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.6.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
     )
     assert result.exit_code == 0
 
@@ -254,7 +248,7 @@ def test_run_unknown_private_key():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.6.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
     )
     assert result.exit_code == 0
     result = runner.invoke(
@@ -264,7 +258,7 @@ def test_run_unknown_private_key():
             "config",
             "set",
             "agent.default_connection",
-            "fetchai/http_client:0.6.0",
+            "fetchai/http_client:0.7.0",
         ],
     )
     assert result.exit_code == 0
@@ -293,7 +287,7 @@ def test_run_unknown_private_key():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.6.0"],
+        [*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.7.0"],
         standalone_mode=False,
     )
 
@@ -329,7 +323,7 @@ def test_run_fet_private_key_config():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.6.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
     )
     assert result.exit_code == 0
 
@@ -353,7 +347,7 @@ def test_run_fet_private_key_config():
 
     error_msg = ""
     try:
-        cli.main([*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.6.0"])
+        cli.main([*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.7.0"])
     except SystemExit as e:
         error_msg = str(e)
 
@@ -388,7 +382,7 @@ def test_run_ethereum_private_key_config():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.6.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
     )
     assert result.exit_code == 0
 
@@ -412,7 +406,7 @@ def test_run_ethereum_private_key_config():
 
     error_msg = ""
     try:
-        cli.main([*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.6.0"])
+        cli.main([*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.7.0"])
     except SystemExit as e:
         error_msg = str(e)
 
@@ -450,7 +444,7 @@ def test_run_with_install_deps():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.6.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
     )
     assert result.exit_code == 0
     result = runner.invoke(
@@ -460,7 +454,7 @@ def test_run_with_install_deps():
             "config",
             "set",
             "agent.default_connection",
-            "fetchai/http_client:0.6.0",
+            "fetchai/http_client:0.7.0",
         ],
     )
     assert result.exit_code == 0
@@ -476,7 +470,7 @@ def test_run_with_install_deps():
                 "run",
                 "--install-deps",
                 "--connections",
-                "fetchai/http_client:0.6.0",
+                "fetchai/http_client:0.7.0",
             ],
             env=os.environ,
             maxread=10000,
@@ -522,7 +516,7 @@ def test_run_with_install_deps_and_requirement_file():
 
     result = runner.invoke(
         cli,
-        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.6.0"],
+        [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/http_client:0.7.0"],
     )
     assert result.exit_code == 0
     result = runner.invoke(
@@ -532,7 +526,7 @@ def test_run_with_install_deps_and_requirement_file():
             "config",
             "set",
             "agent.default_connection",
-            "fetchai/http_client:0.6.0",
+            "fetchai/http_client:0.7.0",
         ],
     )
     assert result.exit_code == 0
@@ -552,7 +546,7 @@ def test_run_with_install_deps_and_requirement_file():
                 "run",
                 "--install-deps",
                 "--connections",
-                "fetchai/http_client:0.6.0",
+                "fetchai/http_client:0.7.0",
             ],
             env=os.environ,
             maxread=10000,
@@ -610,7 +604,7 @@ class TestRunFailsWhenExceptionOccursInSkill:
                 "add",
                 "--local",
                 "connection",
-                "fetchai/http_client:0.6.0",
+                "fetchai/http_client:0.7.0",
             ],
             standalone_mode=False,
         )
@@ -627,7 +621,7 @@ class TestRunFailsWhenExceptionOccursInSkill:
 
         try:
             cli.main(
-                [*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.6.0"]
+                [*CLI_LOG_OPTION, "run", "--connections", "fetchai/http_client:0.7.0"]
             )
         except SystemExit as e:
             cls.exit_code = e.code
@@ -822,7 +816,7 @@ class TestRunFailsWhenConnectionConfigFileNotFound:
         """Set the test up."""
         cls.runner = CliRunner()
         cls.agent_name = "myagent"
-        cls.connection_id = PublicId.from_str("fetchai/http_client:0.6.0")
+        cls.connection_id = PublicId.from_str("fetchai/http_client:0.7.0")
         cls.connection_name = cls.connection_id.name
         cls.connection_author = cls.connection_id.author
         cls.cwd = os.getcwd()
@@ -856,7 +850,7 @@ class TestRunFailsWhenConnectionConfigFileNotFound:
                 "config",
                 "set",
                 "agent.default_connection",
-                "fetchai/http_client:0.6.0",
+                "fetchai/http_client:0.7.0",
             ],
         )
         assert result.exit_code == 0
@@ -915,7 +909,7 @@ class TestRunFailsWhenConnectionNotComplete:
         """Set the test up."""
         cls.runner = CliRunner()
         cls.agent_name = "myagent"
-        cls.connection_id = PublicId.from_str("fetchai/http_client:0.6.0")
+        cls.connection_id = PublicId.from_str("fetchai/http_client:0.7.0")
         cls.connection_author = cls.connection_id.author
         cls.connection_name = cls.connection_id.name
         cls.cwd = os.getcwd()
@@ -949,7 +943,7 @@ class TestRunFailsWhenConnectionNotComplete:
                 "config",
                 "set",
                 "agent.default_connection",
-                "fetchai/http_client:0.6.0",
+                "fetchai/http_client:0.7.0",
             ],
         )
         assert result.exit_code == 0
@@ -1007,7 +1001,7 @@ class TestRunFailsWhenConnectionClassNotPresent:
         """Set the test up."""
         cls.runner = CliRunner()
         cls.agent_name = "myagent"
-        cls.connection_id = "fetchai/http_client:0.6.0"
+        cls.connection_id = "fetchai/http_client:0.7.0"
         cls.connection_name = "http_client"
         cls.cwd = os.getcwd()
         cls.t = tempfile.mkdtemp()
@@ -1040,7 +1034,7 @@ class TestRunFailsWhenConnectionClassNotPresent:
                 "config",
                 "set",
                 "agent.default_connection",
-                "fetchai/http_client:0.6.0",
+                "fetchai/http_client:0.7.0",
             ],
         )
         assert result.exit_code == 0
@@ -1248,6 +1242,23 @@ def _raise_click_exception(*args, **kwargs):
 class RunAEATestCase(TestCase):
     """Test case for run_aea method."""
 
+    def test_run_aea_positive_mock(self):
+        """Test run_aea method for positive result (mocked)."""
+        ctx = mock.Mock()
+        aea = mock.Mock()
+        ctx.config = {"skip_consistency_check": True}
+        with mock.patch("aea.cli.run._build_aea", return_value=aea):
+            run_aea(ctx, ["author/name:0.1.0"], "env_file", False)
+
+    def test_run_aea_positive_install_deps_mock(self):
+        """Test run_aea method for positive result (mocked), install deps true."""
+        ctx = mock.Mock()
+        aea = mock.Mock()
+        ctx.config = {"skip_consistency_check": True}
+        with mock.patch("aea.cli.run.do_install"):
+            with mock.patch("aea.cli.run._build_aea", return_value=aea):
+                run_aea(ctx, ["author/name:0.1.0"], "env_file", True)
+
     @mock.patch("aea.cli.run._prepare_environment", _raise_click_exception)
     def test_run_aea_negative(self, *mocks):
         """Test run_aea method for negative result."""
