@@ -18,6 +18,7 @@
 # ------------------------------------------------------------------------------
 
 """This module contains the tests for the aea.configurations.base module."""
+import re
 from pathlib import Path
 from unittest import TestCase, mock
 
@@ -57,7 +58,6 @@ from tests.conftest import (
     contract_config_files,
     protocol_config_files,
     skill_config_files,
-    skip_test_windows,
 )
 
 
@@ -129,6 +129,20 @@ class TestContractConfig:
         actual_json = actual_config.json
         assert expected_json == actual_json
 
+    @pytest.mark.parametrize("contract_path", contract_config_files)
+    def test_contract_interfaces_getter(self, contract_path):
+        """Test the '_get_contract_interfaces' method and 'contract_interfaces' property work correctly."""
+        f = open(contract_path)
+        original_json = yaml.safe_load(f)
+
+        config = ContractConfig.from_json(original_json)
+        config.directory = Path(contract_path).parent
+        assert config.contract_interfaces != {}
+        assert (
+            "cosmos" in config.contract_interfaces
+            and "ethereum" in config.contract_interfaces
+        )
+
 
 class TestConnectionConfig:
     """Test the connection configuration class."""
@@ -483,13 +497,12 @@ def test_component_configuration_check_fingerprint_bad_directory():
         config.check_fingerprint(Path("non_existing_directory"))
 
 
-@skip_test_windows
 def test_component_configuration_check_fingerprint_different_fingerprints_vendor():
     """Test ComponentConfiguration.check_fingerprint when the fingerprints differ for a vendor package."""
     config = ProtocolConfig("name", "author", "0.1.0")
     package_dir = Path("path", "to", "dir")
     error_regex = (
-        f"Fingerprints for package {package_dir} do not match:\nExpected: {dict()}\nActual: {dict(foo='bar')}\n"
+        f"Fingerprints for package {re.escape(str(package_dir))} do not match:\nExpected: {dict()}\nActual: {dict(foo='bar')}\n"
         + "Vendorized projects should not be tampered with, please revert any changes to protocol author/name:0.1.0"
     )
 
@@ -500,13 +513,12 @@ def test_component_configuration_check_fingerprint_different_fingerprints_vendor
             _compare_fingerprints(config, package_dir, True, PackageType.PROTOCOL)
 
 
-@skip_test_windows
 def test_component_configuration_check_fingerprint_different_fingerprints_no_vendor():
     """Test ComponentConfiguration.check_fingerprint when the fingerprints differ for a non-vendor package."""
     config = ProtocolConfig("name", "author", "0.1.0")
     package_dir = Path("path", "to", "dir")
     error_regex = (
-        f"Fingerprints for package {package_dir} do not match:\nExpected: {dict()}\nActual: {dict(foo='bar')}\n"
+        f"Fingerprints for package {re.escape(str(package_dir))} do not match:\nExpected: {dict()}\nActual: {dict(foo='bar')}\n"
         + "Please fingerprint the package before continuing: 'aea fingerprint protocol author/name:0.1.0"
     )
 
