@@ -23,8 +23,9 @@ import logging
 import os
 from pathlib import Path
 
-from ..helper import extract_code_blocks, read_md_file
-from ...conftest import ROOT_DIR
+from tests.conftest import ROOT_DIR
+from tests.test_docs.helper import extract_code_blocks, read_md_file
+
 
 logger = logging.getLogger(__name__)
 
