@@ -25,6 +25,7 @@ from threading import Thread
 
 from aea.aea_builder import AEABuilder
 from aea.configurations.base import SkillConfig
+from aea.connections.stub.connection import write_with_lock
 from aea.crypto.cosmos import CosmosCrypto
 from aea.crypto.helpers import COSMOS_PRIVATE_KEY_FILE, create_private_key
 from aea.skills.base import Skill
@@ -95,19 +96,17 @@ def run():
         time.sleep(4)
 
         # Create a message inside an envelope and get the stub connection to pass it on to the echo skill
-        message_text = (
-            "my_aea,other_agent,fetchai/default:0.4.0,\x08\x01*\x07\n\x05hello,"
-        )
-        with open(INPUT_FILE, "w") as f:
-            f.write(message_text)
-            print("input message: " + message_text)
+        message_text = b"my_aea,other_agent,fetchai/default:0.4.0,\x08\x01\x12\x011*\x07\n\x05hello,"
+        with open(INPUT_FILE, "wb") as f:
+            write_with_lock(f, message_text)
+            print(b"input message: " + message_text)
 
         # Wait for the envelope to get processed
         time.sleep(4)
 
         # Read the output envelope generated by the echo skill
-        with open(OUTPUT_FILE, "r") as f:
-            print("output message: " + f.readline())
+        with open(OUTPUT_FILE, "rb") as f:
+            print(b"output message: " + f.readline())
     finally:
         # Shut down the AEA
         my_aea.stop()
