@@ -22,9 +22,10 @@
 import os
 from pathlib import Path
 
+
 from aea.test_tools.test_cases import BaseAEATestCase
 
-from tests.conftest import CUR_PATH, ROOT_DIR, skip_test_windows
+from tests.conftest import CUR_PATH, ROOT_DIR
 from tests.test_docs.helper import extract_code_blocks, extract_python_code
 
 from .multiplexer_standalone import run
@@ -52,7 +53,6 @@ class TestMultiplexerStandAlone(BaseAEATestCase):
             self.code_blocks[-1] == self.python_file
         ), "Files must be exactly the same."
 
-    @skip_test_windows
     def test_run_agent(self):
         """Run the agent from the file."""
         run()
