@@ -20,8 +20,9 @@
 """This module contains the tests for the ipfs helper module."""
 
 import os
+from unittest.mock import patch
 
-from aea.helpers.ipfs.base import IPFSHashOnly
+from aea.helpers.ipfs.base import IPFSHashOnly, _is_text
 
 from tests.conftest import CUR_PATH
 
@@ -32,3 +33,13 @@ def test_get_hash():
     """Test get hash IPFSHashOnly."""
     ipfs_hash = IPFSHashOnly().get(file_path=os.path.join(CUR_PATH, FILE_PATH))
     assert ipfs_hash == "QmWeMu9JFPUcYdz4rwnWiJuQ6QForNFRsjBiN5PtmkEg4A"
+
+
+def test_is_text_negative():
+    """Test the helper method 'is_text' negative case."""
+    # https://gehrcke.de/2015/12/how-to-raise-unicodedecodeerror-in-python-3/
+    with patch(
+        "builtins.open",
+        side_effect=UnicodeDecodeError("foo", b"bytes", 1, 2, "Fake reason"),
+    ):
+        assert not _is_text("path")
