@@ -23,15 +23,33 @@ import os
 import shutil
 import tempfile
 from pathlib import Path
+from typing import List, Tuple, Type
+from unittest.mock import MagicMock
+
+import pytest
 
 from aea import AEA_DIR
 from aea.configurations.constants import DEFAULT_PROTOCOL
+from aea.helpers.dialogue.base import DialogueLabel
 from aea.mail.base import Envelope
 from aea.protocols.base import JSONSerializer, Message, ProtobufSerializer, Protocol
+from aea.protocols.default.dialogues import DefaultDialogue, DefaultDialogues
+from aea.protocols.signing.dialogues import SigningDialogue, SigningDialogues
+from aea.protocols.state_update.dialogues import (
+    StateUpdateDialogue,
+    StateUpdateDialogues,
+)
 
 from tests.conftest import UNKNOWN_PROTOCOL_PUBLIC_ID
 
 
+DIALOGUE_CLASSES: List[Tuple[Type, Type]] = [
+    (DefaultDialogue, DefaultDialogues),
+    (SigningDialogue, SigningDialogues),
+    (StateUpdateDialogue, StateUpdateDialogues),
+]
+
+
 class TestMessageProperties:
     """Test that the base serializations work."""
 
@@ -142,3 +160,65 @@ class TestProtocolFromDir:
             shutil.rmtree(cls.t)
         except (OSError, IOError):
             pass
+
+
+class TestMessageAttributes:
+    """Test some message attributes."""
+
+    def test_performative(self):
+        """Test message performative."""
+
+        class SomePerformative(Message.Performative):
+            value = "value"
+
+        message = Message(performative=SomePerformative.value)
+        assert message.performative == SomePerformative.value
+        assert str(message.performative) == "value"
+
+    def test_to(self):
+        """Test the 'to' attribute getter and setter."""
+        message = Message()
+        with pytest.raises(AssertionError, match="To must not be None."):
+            message.to
+
+        message.to = "to"
+        assert message.to == "to"
+
+        with pytest.raises(AssertionError, match="To already set."):
+            message.to = "to"
+
+    def test_dialogue_reference(self):
+        """Test the 'dialogue_reference' attribute."""
+        message = Message(dialogue_reference=("x", "y"))
+        assert message.dialogue_reference == ("x", "y")
+
+    def test_message_id(self):
+        """Test the 'message_id' attribute."""
+        message = Message(message_id=1)
+        assert message.message_id == 1
+
+    def test_target(self):
+        """Test the 'target' attribute."""
+        message = Message(target=1)
+        assert message.target == 1
+
+
+@pytest.mark.parametrize("dialogue_classes", DIALOGUE_CLASSES)
+def test_dialogue(dialogue_classes):
+    """Test dialogue initialization."""
+    dialogue_class, _ = dialogue_classes
+    dialogue = dialogue_class(DialogueLabel(("x", "y"), "opponent_addr", "starer_addr"))
+    assert dialogue.is_valid(MagicMock())
+
+
+@pytest.mark.parametrize("dialogues_classes", DIALOGUE_CLASSES)
+def test_default_dialogues(dialogues_classes):
+    """Test default dialogues initialization."""
+    dialogue_class, dialogues_class = dialogues_classes
+    dialogues = dialogues_class("agent_address")
+
+    dialogue = dialogues.create_dialogue(
+        DialogueLabel(("x", "y"), "opponent_addr", "starter_addr"),
+        next(iter(dialogue_class.Role)),
+    )
+    assert isinstance(dialogue, dialogue_class)
