@@ -17,7 +17,6 @@
 #
 # ------------------------------------------------------------------------------
 """This module contains miscellaneous tests for the protocol generator."""
-import filecmp
 import logging
 import os
 import shutil
@@ -34,7 +33,7 @@ from aea.configurations.base import (
 )
 from aea.protocols.generator.base import ProtocolGenerator
 
-from tests.conftest import ROOT_DIR, skip_test_windows
+from tests.conftest import ROOT_DIR
 from tests.data.generator.t_protocol.message import (  # type: ignore
     TProtocolMessage,
 )
@@ -49,7 +48,12 @@ logger = logging.getLogger("aea")
 logging.basicConfig(level=logging.INFO)
 
 
-@skip_test_windows
+def _match_files(fname1: str, fname2: str) -> bool:
+    """Simple match file function."""
+    with open(fname1, "r") as f1, open(fname2, "r") as f2:
+        return f1.read() == f2.read()
+
+
 class TestCompareLatestGeneratorOutputWithTestProtocol:
     """Test that the "t_protocol" test protocol matches with the latest generator output based on its specification."""
 
@@ -59,7 +63,6 @@ class TestCompareLatestGeneratorOutputWithTestProtocol:
         cls.cwd = os.getcwd()
         cls.t = tempfile.mkdtemp()
         os.chdir(cls.t)
-        filecmp.clear_cache()
 
     def test_compare_latest_generator_output_with_test_protocol(self):
         """
@@ -90,22 +93,22 @@ class TestCompareLatestGeneratorOutputWithTestProtocol:
         # compare __init__.py
         init_file_generated = Path(self.t, T_PROTOCOL_NAME, "__init__.py")
         init_file_original = Path(PATH_TO_T_PROTOCOL, "__init__.py",)
-        assert filecmp.cmp(init_file_generated, init_file_original)
+        assert _match_files(init_file_generated, init_file_original)
 
         # compare message.py
         message_file_generated = Path(self.t, T_PROTOCOL_NAME, "message.py")
         message_file_original = Path(PATH_TO_T_PROTOCOL, "message.py",)
-        assert filecmp.cmp(message_file_generated, message_file_original)
+        assert _match_files(message_file_generated, message_file_original)
 
         # compare serialization.py
         serialization_file_generated = Path(self.t, T_PROTOCOL_NAME, "serialization.py")
         serialization_file_original = Path(PATH_TO_T_PROTOCOL, "serialization.py",)
-        assert filecmp.cmp(serialization_file_generated, serialization_file_original)
+        assert _match_files(serialization_file_generated, serialization_file_original)
 
         # compare dialogues.py
         dialogue_file_generated = Path(self.t, T_PROTOCOL_NAME, "dialogues.py")
         dialogue_file_original = Path(PATH_TO_T_PROTOCOL, "dialogues.py",)
-        assert filecmp.cmp(dialogue_file_generated, dialogue_file_original)
+        assert _match_files(dialogue_file_generated, dialogue_file_original)
 
         # compare .proto
         proto_file_generated = Path(
@@ -114,7 +117,7 @@ class TestCompareLatestGeneratorOutputWithTestProtocol:
         proto_file_original = Path(
             PATH_TO_T_PROTOCOL, "{}.proto".format(T_PROTOCOL_NAME),
         )
-        assert filecmp.cmp(proto_file_generated, proto_file_original, shallow=False)
+        assert _match_files(proto_file_generated, proto_file_original)
 
         # compare _pb2.py
         # ToDo Fails in CI. Investigate!
@@ -136,7 +139,6 @@ class TestCompareLatestGeneratorOutputWithTestProtocol:
             pass
 
 
-@skip_test_windows
 class TestCompareLatestGeneratorOutputWithTestProtocolWithNoCustomTypes:
     """Test that the "t_protocol" test protocol matches with the latest generator output based on its specification."""
 
@@ -146,7 +148,6 @@ class TestCompareLatestGeneratorOutputWithTestProtocolWithNoCustomTypes:
         cls.cwd = os.getcwd()
         cls.t = tempfile.mkdtemp()
         os.chdir(cls.t)
-        filecmp.clear_cache()
 
     def test_compare_latest_generator_output_with_test_protocol(self):
         """
@@ -185,29 +186,29 @@ class TestCompareLatestGeneratorOutputWithTestProtocolWithNoCustomTypes:
         # compare __init__.py
         init_file_generated = Path(self.t, protocol_name, "__init__.py")
         init_file_original = Path(path_to_protocol, "__init__.py",)
-        assert filecmp.cmp(init_file_generated, init_file_original)
+        assert _match_files(init_file_generated, init_file_original)
 
         # compare message.py
         message_file_generated = Path(self.t, protocol_name, "message.py")
         message_file_original = Path(path_to_protocol, "message.py",)
-        assert filecmp.cmp(message_file_generated, message_file_original)
+        assert _match_files(message_file_generated, message_file_original)
 
         # compare serialization.py
         serialization_file_generated = Path(self.t, protocol_name, "serialization.py")
         serialization_file_original = Path(path_to_protocol, "serialization.py",)
-        assert filecmp.cmp(serialization_file_generated, serialization_file_original)
+        assert _match_files(serialization_file_generated, serialization_file_original)
 
         # compare dialogues.py
         dialogue_file_generated = Path(self.t, protocol_name, "dialogues.py")
         dialogue_file_original = Path(path_to_protocol, "dialogues.py",)
-        assert filecmp.cmp(dialogue_file_generated, dialogue_file_original)
+        assert _match_files(dialogue_file_generated, dialogue_file_original)
 
         # compare .proto
         proto_file_generated = Path(
             self.t, protocol_name, "{}.proto".format(protocol_name)
         )
         proto_file_original = Path(path_to_protocol, "{}.proto".format(protocol_name),)
-        assert filecmp.cmp(proto_file_generated, proto_file_original)
+        assert _match_files(proto_file_generated, proto_file_original)
 
         # compare _pb2.py
         # ToDo Fails in CI. Investigate!
